<?php
namespace SupplyTek\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use SupplyTek\Utilities\CrudSupplyTek;
use SupplyTek\Utilities\SessionHandler;

/**
 * Search for product category information.
 *
 * @author Grazielle Ferreira Antunes Brum
 */
class CategoriesController 
{
    protected $crud;
    protected $sessionHandler;

    public function __construct ($crudSupplyTek, $sessionHandler) 
    {
        $this->crud = $crudSupplyTek;
        $this->sessionHandler = $sessionHandler;
    }

    /**
     * Returns all product categories to the front end.
     * 
     * @param Request $request – Object that receives data from the caller.
     * @param Response $response –  Object that sends Nback data to the caller.
     * 
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Grazielle Ferreira Antunes Brum
     */
    public function getCategories(Request $request, Response $response)
    {
        try {
            $categories = $this->crud->find($request);

            $response->setMetadata($categories);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Returns all product categories to the front end.
     * 
     * @param Request $request – Object that receives data from the caller.
     * @param Response $response –  Object that sends Nback data to the caller.
     * 
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function getFeaturedCategories(Request $request, Response $response)
    {
        try {
            $operatorId = $this->sessionHandler->getSessionData('CDOPERADOR');
            $unitId = $this->sessionHandler->getSessionData('CDFILIAL');
            
            $params = array(
                "UNIT_ID" => $unitId,
                "OPERATOR_ID" => $operatorId
            );
            
            $categories = $this->crud->find($request, $params);

            $response->setMetadata($categories);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    /**
     * Return details needed from category request
     * 
     * Retrieves the data needed for the category request, that is
     * the category id and the category name.
     * 
     * @param Request $request Object that receives data from the caller
     * @param Response $response Object that sends back data to the caller
     *
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Rômulo Alves Lousada
     */
    public function getCategoryName(Request $request, Response $response)
    {
        try {
            $categories = $this->crud->find($request);

            $response->setMetadata($categories);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    /**
     * Return details needed from subcategory request
     * 
     * Retrieves the data needed for the subcategory request, that is
     * the subcategory id, subcategory name, category id and category name.
     * 
     * @param Request $request Object that receives data from the caller
     * @param Response $response Object that sends back data to the caller
     *
     * @return array
     * @throws Exception
     * 
     * @access public
     * @author Pedro Henrique Vilaça Valverde
     */
    public function getSubcategoryName(Request $request, Response $response)
    {
        try {
            $categories = $this->crud->find($request);

            $response->setMetadata($categories);
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
