<?php
namespace SupplyTek\Services;

use Zeedhi\Framework\DependencyInjection\InstanceManager;
use SupplyTek\Utilities\ConnectionCustom;

class PrivacyPolicyService
{
    
    public function __construct (ConnectionCustom $connectionCustom) 
    {
        $this->connectionCustom = $connectionCustom;
    }
    
    public function findPrivacyPolicyByAuthentication($user)
    {
        $connectionParams = self::getConnectionParamsParameter();
        if (!isset($connectionParams['useVpd']) || !$connectionParams['useVpd']) {
            $paramgeral = $this->findPrivacyPolicyPath();
            if(count($paramgeral) == 1) {
                $paramgeral = $paramgeral[0];
            } else if($user) {
                $paramgeral = $this->getPrivacePolicyByUser($user);
            } else {
                return array(array('path' => null, 'status' => false));
            }
        } else {
            if($user) {
                $paramgeral = $this->getPrivacePolicyByUser($user);
            } else {
                return array(array('path' => null, 'status' => false));
            }
        }
        if(empty($paramgeral) || empty($paramgeral['DSARQPOLPRIV'])) {
            return array(array('path' => self::getPrivacyPolicyPathParameter(), 'status' => true));
        } else {
            return array(array('path' => $paramgeral['DSARQPOLPRIV'], 'status' => true));
        }
    }
    
    public function findPrivacyPolicyPath()
    {
        $query = "SELECT DSARQPOLPRIV
                    FROM PARAMGERAL";

        $entityManager = self::getEntityManager();
        return $entityManager->getConnection()->fetchAll($query);
    }
    
    private function getPrivacePolicyByUser($user) {
        $user = $this->getOperatorByNmAccessOrEmail($user);
        if(empty($user)) {
            throw new \Exception("Usuário não encontrado.");
        } else {
            return $this->findPrivacyPolicyPathByAuthentication($user['ORGANIZATION_ID']);
        }
    }
    
    public function getOperatorByNmAccessOrEmail($operador){
        $query = "SELECT CDOPERADOR AS ID, NMOPERADOR AS NAME, NRORG AS ORGANIZATION_ID, DSEMAILOPER AS EMAIL,
                         CDSENHAOPERWEB AS PASSWORD_MD5, CDSENHOPER AS PASSWORD_CRYPTO_PLUS,
                         CASE WHEN IDOPERATIVO = 'A'
                              THEN 'Y'
                              ELSE 'N'
                          END AS IS_ACTIVE,
                         IDIDIOMA, NMACESSO, NMCOMPLOPER, CDEMPRESA, NRPARCNEGOCIO,
                         NRORG, NRORGTRAB, NRESTRUTTRAB, CDFILIALSELECIONADA, NRORGOPER
                    FROM OPERADOR
                   WHERE UPPER(NMACESSO) = UPPER(:OPERADOR)
                      OR DSEMAILOPER = :OPERADOR";

        $params = array( 'OPERADOR' => $operador );
        
        $entityManager = self::getEntityManager();
        
        $result = $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }
    
    public function findPrivacyPolicyPathByAuthentication($nrOrg)
    {
        $query = "SELECT DSARQPOLPRIV
                    FROM PARAMGERAL
                   WHERE NRORG = :NRORG";

        $params = array(
            'NRORG' => $nrOrg
        );

        $entityManager = $this->connectionCustom->updateVpdConnection($nrOrg);
        
        $entityManager = $entityManager ? $entityManager : self::getEntityManager();
        
        $result =  $entityManager->getConnection()->fetchAll($query, $params);
        return !empty($result) ? $result[0] : $result;
    }
    
    public static function getConnectionParamsParameter() {
        try {
            return InstanceManager::getInstance()->getParameter('connection_params');
        } catch(\Exception $e) {
            return null;
        }
    }
    
    public static function getPrivacyPolicyPathParameter() {
        return InstanceManager::getInstance()->getParameter('privacyPolicyPath');
    }
    
    public static function getEntityManager()
    {
        return InstanceManager::getInstance()->getService('entityManager');
    }
    
}